Crate lan_mouse_proto

Crate lan_mouse_proto 

Enums

EventType
Position
Position of a client
ProtoEvent
main lan-mouse protocol event type
ProtocolError
error type for protocol violations

Constants

MAX_EVENT_SIZE
defines the maximum size an encoded event can take up this is currently the pointer motion event type: u8, time: u32, dx: f64, dy: f64