Enums
- Event
Type - Position
- Position of a client
- Proto
Event - main lan-mouse protocol event type
- Protocol
Error - error type for protocol violations
Constants
- MAX_
EVENT_ SIZE - defines the maximum size an encoded event can take up this is currently the pointer motion event type: u8, time: u32, dx: f64, dy: f64