pub enum ProtoEvent {
Enter(u32),
Leave(u32),
Ack(u32),
Input(Event),
Ping,
Pong,
}Expand description
main lan-mouse protocol event type
Variants
Enter(u32)
notify a client that the cursor entered its region
ProtoEvent::Ack with the same serial is used for synchronization between devices
Leave(u32)
notify a client that the cursor left its region
ProtoEvent::Ack with the same serial is used for synchronization between devices
Ack(u32)
acknowledge of an ProtoEvent::Enter or ProtoEvent::Leave event
Input(Event)
Input event
Ping
Ping event for tracking unresponsive clients.
A client has to respond with ProtoEvent::Pong.
Pong
Response to ProtoEvent::Ping